@@ -4,7 +4,7 @@ from time import sleep
 from bd_time import tt, vk, Time
 from pydamo_0.regsvr import RegDM, run_in_bat
 
-print('This is self_model')
+# print('This is self_model')
 
 class DM:
     def __init__(self):
